.. _contents:

.. image:: _static/cadet_logo.png

|

.. image:: https://img.shields.io/github/release/modsim/CADET-Match.svg
   :target: https://github.com/modsim/CADET-Match/releases

CADETMatch
==========
CADETMatch is a parameter estimation and error modeling library for CADET.
CADETMatch is developed at the Institute of Bio- and Geosciences 1 (IBG-1) of Forschungszentrum Jülich (FZJ) under supervision of Dr. Eric von Lieres.


- **Source:** https://github.com/modsim/CADET-Match
- **Releases:** https://github.com/modsim/CADET-Match/releases

.. rubric:: Features

* Multiple experiments
* Multiple components
* Gradient-Free
* Gradient-Based
* Composable goals
* Python 3
* JSON configuration file
* Parallel

.. rubric:: Ongoing Development

CADETMatch is actively developed and we do our best to prevent breaking changes.
For non-developers, it is recommended to upgrade from release to release instead of always working with the most recent commit.


.. rubric:: Bugs

Please report any bugs that you find `here <https://github.com/modsim/CADET-Match/issues>`_.
Or, even better, fork the repository on `GitHub <https://github.com/modsim/CADET-Match>`_ and create a pull request (PR) with the fix. 

.. toctree::
    :maxdepth: 3
    :hidden:

    install/index
    configuration/index
    cli/index
    license


